import request from '@/utils/request'

// 查询app首页列表
export function listApphome(query) {
  return request({
    url: '/app/apphome/list',
    method: 'get',
    params: query
  })
}

// 查询机构列表
export function orgList(query) {
  return request({
    url: '/app/apphome/orgList',
    method: 'get'
  })
}

// 查询app首页详细
export function getApphome(appHomeId) {
  return request({
    url: '/app/apphome/' + appHomeId,
    method: 'get'
  })
}

// 新增app首页
export function addApphome(data) {
  return request({
    url: '/app/apphome',
    method: 'post',
    data: data
  })
}

// 修改app首页
export function updateApphome(data) {
  return request({
    url: '/app/apphome',
    method: 'put',
    data: data
  })
}

// 删除app首页
export function delApphome(appHomeId) {
  return request({
    url: '/app/apphome/' + appHomeId,
    method: 'delete'
  })
}

// 导出app首页
export function exportApphome(query) {
  return request({
    url: '/app/apphome/export',
    method: 'get',
    params: query
  })
}
