<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="首页编号" prop="appHomeName">
        <el-input
          v-model="queryParams.appHomeName"
          placeholder="请输入首页编号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="机构" prop="orgCode">-->
<!--        <el-select v-model="queryParams.orgCode" placeholder="请选择机构" clearable size="small">-->
<!--          <el-option-->
<!--            v-for="item in orgList"-->
<!--            :key="item.deptCode"-->
<!--            :label="item.deptName"-->
<!--            :value="item.deptCode"/>-->
<!--        </el-select>-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['app:apphome:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['app:apphome:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['app:apphome:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['app:apphome:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="apphomeList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column label="序号" width="55" align="center">
        <template scope="scope">
          {{scope.$index+1}}
        </template>
      </el-table-column>
      <el-table-column label="首页编号" align="center" prop="appHomeName"/>
      <el-table-column label="机构" align="center" prop="orgCode">
        <template scope="scope">
          <el-select v-model="scope.row.orgCode"  :disabled="true" size="small">
            <el-option
              v-for="item in orgList"
              :key="item.deptCode"
              :label="item.deptName"
              :value="item.deptCode"/>
          </el-select>
        </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d} {h}:{i}:{s}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-setting"
            @click="isOpenConfig(scope.row)"
          >配置
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['app:apphome:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['app:apphome:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改app首页对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <el-form-item label="首页编号" prop="appHomeName">
          <el-input v-model="form.appHomeName" placeholder="请输入app首页名称"/>
        </el-form-item>
        <el-form-item label="机构" prop="orgCode">
          <el-select v-model="form.orgCode" placeholder="请选择机构" clearable size="small">
            <el-option
              v-for="item in orgList"
              :key="item.deptCode"
              :label="item.deptName"
              :value="item.deptCode"/>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <el-dialog v-loading="dataLoading" :fullscreen="true" title="首页配置" :visible.sync="isOpenConfigPage"
               :before-close="ai_dialog_close">
      <homeConfig ref="homeConfig" :appHomeId="appHomeId" :homeContentId="homeId"></homeConfig>
    </el-dialog>
  </div>
</template>

<script>
  import {
    addApphome,
    delApphome,
    exportApphome,
    getApphome,
    listApphome,
    orgList,
    updateApphome
  } from "@/api/app/apphome";
  import homeConfig from '../config2/index'
  import user from "@/store/modules/user";

  export default {
    name: "Apphome",
    components: {
      homeConfig
    },
    data() {
      return {
        //窗口加载
        dataLoading: false,
        // 遮罩层
        loading: true,
        // 导出遮罩层
        exportLoading: false,
        isOpenConfigPage: false,
        // 选中数组
        ids: [],
        // 非单个禁用
        single: true,
        // 非多个禁用
        multiple: true,
        // 显示搜索条件
        showSearch: true,
        // 总条数
        total: 0,
        // app首页表格数据
        apphomeList: [],
        // 弹出层标题
        title: "",
        // 是否显示弹出层
        open: false,
        // 查询参数
        queryParams: {
          pageNum: 1,
          pageSize: 10,
          homeId: null,
          appHomeName: null,
          orgCode: null,
        },
        homeId: '',
        appHomeId: '',
        // 表单参数
        form: {},
        orgList: [],
        // 表单校验
        rules: {
          appHomeName: [
            {required: true, message: "首页编号不能为空", trigger: "blur"}
          ],
        }
      };
    },
    created() {
      this.getList();
      this.getOrgList()
    },
    methods: {
      ai_dialog_close() {
        //关闭弹框
        this.isOpenConfigPage = false;
      },
      /*打开配置页面*/
      isOpenConfig(item) {
        this.dataLoading = true
        this.homeId = ''
        if (this.isOpenConfigPage) {
          this.isOpenConfigPage = false
        } else {
          this.isOpenConfigPage = true
          this.homeId = item.homeId
          this.appHomeId = item.appHomeId
          setTimeout(() => {
            this.$refs.homeConfig.getHomeDataReq()
          }, 100)
        }
        setTimeout(() => {
          this.dataLoading = false
        }, 1000)
      },
      /** 查询app首页列表 */
      getList() {
        this.loading = true;
        this.queryParams.orgCode = user.state.organ
        listApphome(this.queryParams).then(response => {
          this.apphomeList = response.rows;
          this.total = response.total;
          this.loading = false;
        });
      },
      /** 查询app首页列表 */
      getOrgList() {
        orgList().then(response => {
          this.orgList = response.data;
        });
      },
      // 取消按钮
      cancel() {
        this.open = false;
        this.openConfigPage = false;
        this.reset();
      },
      // 表单重置
      reset() {
        this.form = {
          appHomeId: null,
          homeId: null,
          appHomeName: null,
          orgCode: null,
          isDelete: null,
          createBy: null,
          createTime: null,
          updateBy: null,
          updateTime: null,
          remark: null
        };
        this.resetForm("form");
      },
      /** 搜索按钮操作 */
      handleQuery() {
        this.queryParams.pageNum = 1;
        this.getList();
      },
      /** 重置按钮操作 */
      resetQuery() {
        this.resetForm("queryForm");
        this.handleQuery();
      },
      // 多选框选中数据
      handleSelectionChange(selection) {
        this.ids = selection.map(item => item.appHomeId)
        this.single = selection.length !== 1
        this.multiple = !selection.length
      },
      /** 新增按钮操作 */
      handleAdd() {
        this.reset();
        this.open = true;
        this.title = "添加app首页";
      },
      /** 修改按钮操作 */
      handleUpdate(row) {
        this.reset();
        const appHomeId = row.appHomeId || this.ids
        getApphome(appHomeId).then(response => {
          this.form = response.data;
          this.open = true;
          this.title = "修改app首页";
        });
      },
      /** 提交按钮 */
      submitForm() {
        this.$refs["form"].validate(valid => {
          if (valid) {
            if (this.form.appHomeId != null) {
              updateApphome(this.form).then(response => {
                this.$modal.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              });
            } else {
              addApphome(this.form).then(response => {
                this.$modal.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              });
            }
          }
        });
      },
      /** 删除按钮操作 */
      handleDelete(row) {
        const appHomeIds = row.appHomeId || this.ids;
        this.$modal.confirm('是否确认删除app首页编号为"' + appHomeIds + '"的数据项？').then(function () {
          return delApphome(appHomeIds);
        }).then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        }).catch(() => {
        });
      },
      /** 导出按钮操作 */
      handleExport() {
        const queryParams = this.queryParams;
        this.$modal.confirm('是否确认导出所有app首页数据项？').then(() => {
          this.exportLoading = true;
          return exportApphome(queryParams);
        }).then(response => {
          this.$download.name(response.msg);
          this.exportLoading = false;
        }).catch(() => {
        });
      }
    }
  };
</script>
